@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2020 Team Kodi (https://kodi.tv)
+ *  Copyright (C) 2020-2021 Team Kodi (https://kodi.tv)
  *  Copyright (C) 2014 Fred Hoogduin
  *  Copyright (C) 2010 Marcel Groothuis
  *
@@ -21,6 +21,7 @@
 #include "utils.h"
 
 #include <kodi/General.h>
+#include <kodi/tools/StringUtils.h>
 #include <chrono>
 #include <map>
 #include <thread>
@@ -88,6 +89,7 @@ PVR_ERROR cPVRClientArgusTV::GetCapabilities(kodi::addon::PVRCapabilities& capab
   capabilities.SetSupportsRecordingsRename(true);
   capabilities.SetSupportsRecordingsLifetimeChange(false);
   capabilities.SetSupportsDescrambleInfo(false);
+  capabilities.SetSupportsRecordingEdl(true);
 
   return PVR_ERROR_NO_ERROR;
 }
@@ -706,8 +708,13 @@ PVR_ERROR cPVRClientArgusTV::GetRecordings(bool deleted,
             {
               kodi::addon::PVRRecording tag;
 
-              tag.SetSeriesNumber(PVR_RECORDING_INVALID_SERIES_EPISODE);
-              tag.SetEpisodeNumber(PVR_RECORDING_INVALID_SERIES_EPISODE);
+              //There may be cases where series and/or episode are populated withe 0 by default
+              //if neither value is more than 0, there is no value to use or show them
+              if(recording.SeriesNumber() > 0 || recording.EpisodeNumber() > 0)
+              {
+                tag.SetSeriesNumber(recording.SeriesNumber());
+                tag.SetEpisodeNumber(recording.EpisodeNumber());
+              }
 
               tag.SetRecordingId(recording.RecordingId());
               tag.SetChannelName(recording.ChannelDisplayName());
@@ -718,20 +725,10 @@ PVR_ERROR cPVRClientArgusTV::GetRecordings(bool deleted,
               tag.SetPlot(recording.Description());
               tag.SetPlayCount(recording.FullyWatchedCount());
               tag.SetLastPlayedPosition(recording.LastWatchedPosition());
-              if (nrOfRecordings > 1 || m_base.GetSettings().UseFolder())
-              {
-                recording.Transform(true);
-                tag.SetDirectory(
-                    recordinggroup
-                        .ProgramTitle()); //used in Kodi as directory structure below "Server X - hostname"
-              }
-              else
-              {
-                recording.Transform(false);
-                tag.SetDirectory("");
-              }
               tag.SetTitle(recording.Title());
-              tag.SetPlotOutline(recording.SubTitle());
+              tag.SetEpisodeName(recording.SubTitle());
+              if (nrOfRecordings > 1 || m_base.GetSettings().UseFolder())
+                tag.SetDirectory(recording.Title()); 
 
               m_RecordingsMap[tag.GetRecordingId()] = recording.RecordingFileName();
 
@@ -867,6 +864,63 @@ PVR_ERROR cPVRClientArgusTV::SetRecordingPlayCount(const kodi::addon::PVRRecordi
   return PVR_ERROR_NO_ERROR;
 }
 
+// GetRecordingEdl source borrowed from pvr.wmc
+PVR_ERROR cPVRClientArgusTV::GetRecordingEdl(const kodi::addon::PVRRecording& recording,
+                                             std::vector<kodi::addon::PVREDLEntry>& edl)
+{
+  std::string streamFileName; // the name of the stream file
+  if (!FindRecEntry(recording.GetRecordingId(), streamFileName))
+    return PVR_ERROR_SERVER_ERROR;
+
+  if (!streamFileName.empty()) // read the edl for the current stream file
+  {
+    // see if edl file for currently streaming recording exists
+    std::string theEdlFile = streamFileName;
+    // swap .wtv extension for .edl
+    std::string::size_type result = theEdlFile.find_last_of('.');
+    if (std::string::npos != result)
+      theEdlFile.erase(result);
+    else
+    {
+      kodi::Log(ADDON_LOG_DEBUG, "File extender error: '%s'", theEdlFile.c_str());
+      return PVR_ERROR_FAILED;
+    }
+    theEdlFile.append(".edl");
+
+    kodi::Log(ADDON_LOG_DEBUG, "Opening EDL file: '%s'", theEdlFile.c_str());
+
+    kodi::vfs::CFile fileHandle;
+    if (fileHandle.OpenFile(theEdlFile))
+    {
+      std::string svals;
+      while (fileHandle.ReadLine(svals))
+      {
+        size_t nidx = svals.find_last_not_of("\r");
+        svals.erase(svals.npos == nidx ? 0 : ++nidx); // trim windows /r if its there
+
+        std::vector<std::string> vals = kodi::tools::StringUtils::Split(svals, "\t"); // split on tabs
+        if (vals.size() == 3)
+        {
+          kodi::addon::PVREDLEntry entry;
+          entry.SetStart(static_cast<int64_t>(std::strtod(vals[0].c_str(), nullptr) *
+                                              1000)); // convert s to ms
+          entry.SetEnd(static_cast<int64_t>(std::strtod(vals[1].c_str(), nullptr) * 1000));
+          entry.SetType(PVR_EDL_TYPE(atoi(vals[2].c_str())));
+          edl.emplace_back(entry);
+        }
+      }
+      if (!edl.empty())
+        kodi::Log(ADDON_LOG_DEBUG, "EDL data found.");
+      else
+        kodi::Log(ADDON_LOG_DEBUG, "No EDL data found.");
+      return PVR_ERROR_NO_ERROR;
+    }
+    else
+      kodi::Log(ADDON_LOG_DEBUG, "No EDL file found.");
+  }
+  return PVR_ERROR_FAILED;
+}
+
 
 /************************************************************/
 /** Timer handling */
